bayespy.nodes.GaussianGamma.get_gaussian_mean_and_variance
==========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGamma.get_gaussian_mean_and_variance